function simData = UpdateSimData(simData,k,syst,agent,estC,u_nextStep,gamma_syncAvg)
% Storing simulation data.
% 
% Inputs:
%   k           time index
%   syst        system struct, carrying state, measurements etc.
%   agent       all agents' state struct
%   estC        centralized estimator's state struct
%   u_nextStep      control input applied in next loop execution
%   gamma_syncAvg   indicator for sync avg at this step
%
% Output:
%   simData     struct containing all (relevant) simulation data/results
%
% --
% Supplementary material (simulation examples) to:
%   Distributed Event-based State Estimation (technical report)
%   Event-based State Estimation: An Emulation-based Approach (journal)
%
% Copyright 2015-17 Max Planck Society. All rights reserved.
% 
% Sebastian Trimpe
% Max Planck Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%
% Revision history
% [01.04.15]    first version
% [03.08.15]    some clean up

% System trajectory
simData.x(k,:) = syst.x';
simData.y(k,:) = syst.y';
simData.u(k,:) = u_nextStep';
simData.d(k,:) = syst.d';

% Synchronous averaging
simData.gamma_syncAvg(k,:) = gamma_syncAvg;

% Agents' data
for i=1:length(agent)
    % Estimation data
    simData.agent(i).xpred(k,:) = agent(i).xpred';
    simData.agent(i).xhat(k,:) = agent(i).xhat';
    simData.agent(i).xhat_full(k,:) = agent(i).xhat_full';
    simData.agent(i).gamma_y(k,:) = agent(i).gamma_y';
    simData.agent(i).uhat(k,:) = agent(i).uhat';
    simData.agent(i).gamma_u(k,:) = agent(i).gamma_u';
    simData.agent(i).diff_u(k,:) = agent(i).diff_u{1};  % normed diff
end;

% Centralized estimator
simData.estC.xhat(k,:) = estC.xhat';
simData.estC.xhat_full(k,:) = estC.xhat_full';
